<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>
	<xsl:key name="keyCities" match="City" use="@State"/>
	<xsl:key name="keyState" match="State" use="@Abbr"/>
	
	<xsl:template match="/">
		<html>
			<head>
				<title>Most Populated Cities by State</title>
			</head>
			<body>
				<xsl:for-each 
					select="//City[generate-id(.)=generate-id(key('keyCities',@State))]">
					<!--
						The first generate-id() above returns an id for the current City.
						The second generate-id() above returns an id for the first 
							City with a State attribute that is the same as the current 
							City's State attribute.
						These values will only be equal for the first City elements 
							with a specific State attribute.
						So, this for-each loops through the each City first to specify
							a particular State.
					-->
					<xsl:sort select="count(key('keyCities',@State))" 
						order="descending" data-type="number"/>
					<h2>
						<xsl:value-of select="position()"/>
						<xsl:text>. </xsl:text>
						<xsl:value-of select="key('keyState',@State)"/>
						<xsl:text> - </xsl:text>
						<xsl:value-of select="count(key('keyCities',@State))"/>
						<xsl:text> Cities</xsl:text>
					</h2>
					<ol>
						<xsl:for-each select="key('keyCities',@State)">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
						<!--
							This nested for-each loops through the City elements that have
								the same value for the State attribute as the current City in
								the outer for-each loop.
						-->
					</ol>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
	
</xsl:stylesheet>